summaryrefslogtreecommitdiffstats
path: root/khtml/khtml_caret_p.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /khtml/khtml_caret_p.h
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'khtml/khtml_caret_p.h')
-rw-r--r--khtml/khtml_caret_p.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/khtml/khtml_caret_p.h b/khtml/khtml_caret_p.h
index a5c4bf60d..9524f2df7 100644
--- a/khtml/khtml_caret_p.h
+++ b/khtml/khtml_caret_p.h
@@ -1034,7 +1034,7 @@ public:
*/
int chr() const { return _char; }
/** returns the current character as a tqunicode symbol, substituting
* a blank for a non-text node.
*/
TQChar operator *() const { return TQChar(_char >= 0 ? _char : ' '); }
@@ -1089,7 +1089,7 @@ protected:
CaretBox *box = *copy;
InlineBox *b = box->inlineBox();
if (b && !box->isOutside() && b->isInlineTextBox())
- _char = static_cast<RenderText *>(b->object())->str->s[b->minOffset()].tqunicode();
+ _char = static_cast<RenderText *>(b->object())->str->s[b->minOffset()].unicode();
else
_char = -1;
}
@@ -1034,7 +1034,7 @@ public:
*/
int chr() const { return _char; }
- /** returns the current character as a tqunicode symbol, substituting
+ /** returns the current character as a unicode symbol, substituting
* a blank for a non-text node.
*/